==> kdeutils-4.3.5.tar.bz2: kdeutils-4.3.5/okteta/core/tests/kcharcodeciftest.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2006 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KCHARCODECIFTEST_H
#define KCHARCODECIFTEST_H


// Qt
#include <QtCore/QObject>

namespace KHECore {
class CharCodec;
}


class KCharCodecIfTest : public QObject
{
  Q_OBJECT

  protected:
    KCharCodecIfTest();

  protected: // our API
    virtual KHECore::CharCodec *createCodec() = 0;
    virtual void deleteCodec( KHECore::CharCodec *Codec ) = 0;

  private Q_SLOTS: // test functions
    void init();
    void cleanup();

    void testEncodeDecode();

  private:
    /** pointer to the buffer to test */
    KHECore::CharCodec *CharCodec;
};


inline KCharCodecIfTest::KCharCodecIfTest() : CharCodec( 0 ) {}

#endif

==> kdeutils_4.4.85.orig.tar.bz2: kdeutils-4.4.85/okteta/core/tests/kcharcodeciftest.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2006 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KCHARCODECIFTEST_H
#define KCHARCODECIFTEST_H

// Qt
#include <QtCore/QObject>


namespace Okteta
{
class CharCodec;


class KCharCodecIfTest : public QObject
{
  Q_OBJECT

  protected:
    KCharCodecIfTest();

  protected: // our API
    virtual CharCodec* createCodec() = 0;
    virtual void deleteCodec( CharCodec* codec ) = 0;

  private Q_SLOTS: // test functions
    void init();
    void cleanup();

    void testEncodeDecode();

  private:
    /** pointer to the buffer to test */
    CharCodec* mCharCodec;
};


inline KCharCodecIfTest::KCharCodecIfTest() : mCharCodec( 0 ) {}

}

#endif
